Struct parquet::encoding::DeltaLengthByteArrayEncoder [−][src]
pub struct DeltaLengthByteArrayEncoder<T: DataType> { /* fields omitted */ }
Encoding for byte arrays to separate the length values and the data. The lengths are encoded using DELTA_BINARY_PACKED encoding, data is stored as raw bytes.
Methods
impl<T: DataType> DeltaLengthByteArrayEncoder<T>[src]
impl<T: DataType> DeltaLengthByteArrayEncoder<T>Trait Implementations
impl<T: DataType> Encoder<T> for DeltaLengthByteArrayEncoder<T>[src]
impl<T: DataType> Encoder<T> for DeltaLengthByteArrayEncoder<T>fn put(&mut self, _values: &[T::T]) -> Result<()>[src]
fn put(&mut self, _values: &[T::T]) -> Result<()>Encodes data from values.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding type of this encoder.
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>[src]
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>Flushes the underlying byte buffer that's being processed by this encoder, and return the immutable copy of it. This will also reset the internal state. Read more
impl Encoder<ByteArrayType> for DeltaLengthByteArrayEncoder<ByteArrayType>[src]
impl Encoder<ByteArrayType> for DeltaLengthByteArrayEncoder<ByteArrayType>fn put(&mut self, values: &[ByteArray]) -> Result<()>[src]
fn put(&mut self, values: &[ByteArray]) -> Result<()>Encodes data from values.
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>[src]
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>Flushes the underlying byte buffer that's being processed by this encoder, and return the immutable copy of it. This will also reset the internal state. Read more
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding type of this encoder.