Trait parquet::encoding::Encoder[][src]

pub trait Encoder<T: DataType> {
    fn put(&mut self, values: &[T::T]) -> Result<()>;
fn encoding(&self) -> Encoding;
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>; }

An Parquet encoder for the data type T.

Currently this allocates internal buffers for the encoded values. After done putting values, caller should call flush_buffer() to get an immutable buffer pointer.

Required Methods

Encodes data from values.

Returns the encoding type of this encoder.

Flushes the underlying byte buffer that's being processed by this encoder, and return the immutable copy of it. This will also reset the internal state.

Implementors